==> vdr-1.5.10-micky979.tar.bz2: vdr-1.5.10-micky979/PLUGINS/src/menuorg-0.3/src/pluginmenunode.cpp <==
/*
 * vdr-menuorg - A plugin for the Linux Video Disk Recorder
 * Copyright (C) 2007 Thomas Creutz, Tobias Grimm
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: pluginmenunode.cpp 5982 2007-08-25 18:22:48Z svntobi $
 *
 */

#include "pluginmenunode.h"
#include <vdr/mainmenuitemsprovider.h>
#include <vdr/plugin.h>
#include "pluginitemdefinition.h"
#include "childlock.h"

PluginMenuNode::PluginMenuNode(cPlugin* plugin, int pluginIndex)
{
    _plugin = plugin;
    _pluginIndex = pluginIndex;
}

IMenuItemDefinition* PluginMenuNode::CreateMenuItemDefinition()
{
    return new PluginItemDefinition(_plugin->MainMenuEntry(), _pluginIndex);
}

bool PluginMenuNode::IsHidden()
{
    return (!HasMainMenuEntry()) || ChildLock::IsPluginHidden(_plugin);
}

bool PluginMenuNode::HasMainMenuEntry()
{
    return (_plugin->MainMenuEntry() != NULL);
}

==> vdr-1.5.13-micky979.tar.bz2: vdr-1.5.13-micky979/PLUGINS/src/menuorg-0.3.2/src/pluginmenunode.cpp <==
/*
 * vdr-menuorg - A plugin for the Linux Video Disk Recorder
 * Copyright (C) 2007 Thomas Creutz, Tobias Grimm
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: pluginmenunode.cpp 6560 2007-12-11 00:03:15Z svntobi $
 *
 */

#include "pluginmenunode.h"
#include <vdr/mainmenuitemsprovider.h>
#include <vdr/plugin.h>
#include "pluginitemdefinition.h"
#include "childlock.h"

PluginMenuNode::PluginMenuNode(cPlugin* plugin, int pluginIndex)
{
    _plugin = plugin;
    _pluginIndex = pluginIndex;
}

IMenuItemDefinition* PluginMenuNode::CreateMenuItemDefinition()
{
    return new PluginItemDefinition(this, _plugin->MainMenuEntry(), _pluginIndex);
}

bool PluginMenuNode::IsHidden()
{
    return (!HasMainMenuEntry()) || ChildLock::IsPluginHidden(_plugin);
}

bool PluginMenuNode::HasMainMenuEntry()
{
    return (_plugin->MainMenuEntry() != NULL);
}
